@@ -180,7 +180,7 @@ clutter_vertex_new (gfloat x,
 }
 
 /**
- * clutter_vertex_alloc:
+ * clutter_vertex_alloc: (constructor)
  *
  * Allocates a new, empty #ClutterVertex.
  *
@@ -398,7 +398,7 @@ clutter_point_zero (void)
 }
 
 /**
- * clutter_point_alloc:
+ * clutter_point_alloc: (constructor)
  *
  * Allocates a new #ClutterPoint.
  *
@@ -566,7 +566,7 @@ G_DEFINE_BOXED_TYPE_WITH_CODE (ClutterPoint, clutter_point,
  */
 
 /**
- * clutter_size_alloc:
+ * clutter_size_alloc: (constructor)
  *
  * Allocates a new #ClutterSize.
  *
@@ -748,7 +748,7 @@ clutter_rect_zero (void)
 }
 
 /**
- * clutter_rect_alloc:
+ * clutter_rect_alloc: (constructor)
  *
  * Creates a new, empty #ClutterRect.
  *
@@ -1376,10 +1376,8 @@ clutter_matrix_init_from_array (ClutterMatrix *matrix,
  * Since: 1.12
  */
 ClutterMatrix *
-clutter_matrix_init_from_matrix (ClutterMatrix *a,
-                                 ClutterMatrix *b)
+clutter_matrix_init_from_matrix (ClutterMatrix       *a,
+                                 const ClutterMatrix *b)
 {
-  memcpy (b, a, sizeof (ClutterMatrix));
-
-  return a;
+  return memcpy (a, b, sizeof (ClutterMatrix));
 }
