@@ -461,6 +461,20 @@ struct _ClutterActorBox
  */
 #define CLUTTER_ACTOR_BOX_INIT(x_1,y_1,x_2,y_2)         { (x_1), (y_1), (x_2), (y_2) }
 
+/**
+ * CLUTTER_ACTOR_BOX_INIT_ZERO:
+ *
+ * A simple macro for initializing a #ClutterActorBox to 0 when
+ * declaring it, e.g.:
+ *
+ * |[
+ *   ClutterActorBox box = CLUTTER_ACTOR_BOX_INIT_ZERO;
+ * ]|
+ *
+ * Since: 1.12
+ */
+#define CLUTTER_ACTOR_BOX_INIT_ZERO                     CLUTTER_ACTOR_BOX_INIT (0.f, 0.f, 0.f, 0.f)
+
 GType            clutter_actor_box_get_type      (void) G_GNUC_CONST;
 ClutterActorBox *clutter_actor_box_new           (gfloat                 x_1,
                                                   gfloat                 y_1,
@@ -522,6 +536,10 @@ void             clutter_actor_box_set_size       (ClutterActorBox       *box,
  * @height: height of an actor
  *
  * The rectangle containing an actor's bounding box, measured in pixels.
+ *
+ * <warning>You should not use #ClutterGeometry, or operate on its fields
+ * directly; you should use #cairo_rectangle_int_t or #ClutterRect if you
+ * need a rectangle type, depending on the precision required.</warning>
  */
 struct _ClutterGeometry
 {
@@ -679,12 +697,12 @@ void clutter_interval_register_progress_func (GType               value_type,
 GType clutter_matrix_get_type (void) G_GNUC_CONST;
 
 ClutterMatrix * clutter_matrix_alloc            (void);
-ClutterMatrix * clutter_matrix_init_identity    (ClutterMatrix *matrix);
-ClutterMatrix * clutter_matrix_init_from_array  (ClutterMatrix *matrix,
-                                                 const float    values[16]);
-ClutterMatrix * clutter_matrix_init_from_matrix (ClutterMatrix *a,
-                                                 ClutterMatrix *b);
-void            clutter_matrix_free             (ClutterMatrix *matrix);
+ClutterMatrix * clutter_matrix_init_identity    (ClutterMatrix       *matrix);
+ClutterMatrix * clutter_matrix_init_from_array  (ClutterMatrix       *matrix,
+                                                 const float          values[16]);
+ClutterMatrix * clutter_matrix_init_from_matrix (ClutterMatrix       *a,
+                                                 const ClutterMatrix *b);
+void            clutter_matrix_free             (ClutterMatrix       *matrix);
 
 G_END_DECLS
 
