@@ -37,57 +37,58 @@
  * through the #ClutterScript definition format, but it comes with a
  * convenience C API.
  *
- * #ClutterAnimator is available since Clutter 1.2
+ * <refsect2 id="ClutterAnimator-key-frames">
+ *   <title>Key Frames</title>
+ *   <para>Every animation handled by a #ClutterAnimator can be
+ *   described in terms of "key frames". For each #GObject property
+ *   there can be multiple key frames, each one defined by the end
+ *   value for the property to be computed starting from the current
+ *   value to a specific point in time, using a given easing
+ *   mode.</para>
+ *   <para>The point in time is defined using a value representing
+ *   the progress in the normalized interval of [ 0, 1 ]. This maps
+ *   the value returned by clutter_timeline_get_duration().</para>
+ *   <figure id="easing-modes">
+ *     <title>Key Frames</title>
+ *     <graphic fileref="animator-key-frames.png" format="PNG"/>
+ *   </figure>
+ *   <para>In the image above the duration of the animation is
+ *   represented by the blue line. Each key frame is the white dot,
+ *   along with its progress. The red line represents the computed
+ *   function of time given the easing mode.</para>
+ * </refsect2>
  *
- * #ClutterAnimator has been deprecated in Clutter 1.12. If you
- * want to combine multiple transitions using key frames, use
- * #ClutterKeyframeTransition and #ClutterTransitionGroup instead.
- *
- * ## Key Frames
- *
- * Every animation handled by a #ClutterAnimator can be
- * described in terms of "key frames". For each #GObject property
- * there can be multiple key frames, each one defined by the end
- * value for the property to be computed starting from the current
- * value to a specific point in time, using a given easing
- * mode.
- *
- * The point in time is defined using a value representing
- * the progress in the normalized interval of [ 0, 1 ]. This maps
- * the value returned by clutter_timeline_get_duration().
- *
- * ## ClutterAnimator description for ClutterScript
- *
- * #ClutterAnimator defines a custom "properties" key
- * which allows describing the key frames for objects as
- * an array of key frames.
- *
- * The `properties` array has the following syntax:
- *
- * |[
+ * <refsect2 id="ClutterAnimator-script">
+ *   <title>ClutterAnimator description for #ClutterScript</title>
+ *   <para>#ClutterAnimator defines a custom "properties" property
+ *   which allows describing the key frames for objects.</para>
+ *   <para>The "properties" property has the following syntax:</para>
+ *   <informalexample>
+ *     <programlisting><![CDATA[
  *  {
  *    "properties" : [
  *      {
- *        "object" : object_id
- *        "name" : property_name
- *        "ease-in" : true_or_false
- *        "interpolation" : interpolation_value
+ *        "object" : &lt;id of an object&gt;,
+ *        "name" : &lt;name of the property&gt;,
+ *        "ease-in" : &lt;boolean&gt;,
+ *        "interpolation" : &lt;#ClutterInterpolation value&gt;,
  *        "keys" : [
- *          [ progress, easing_mode, final_value ]
+ *          [ &lt;progress&gt;, &lt;easing mode&gt;, &lt;final value&gt; ]
  *        ]
  *    ]
  *  }
- * ]|
- *
- * The following JSON fragment defines a #ClutterAnimator
- * with the duration of 1 second and operating on the x and y
- * properties of a #ClutterActor named "rect-01", with two frames
- * for each property. The first frame will linearly move the actor
- * from its current position to the 100, 100 position in 20 percent
- * of the duration of the animation; the second will using a cubic
- * easing to move the actor to the 200, 200 coordinates.
- *
- * |[
+ *     ]]></programlisting>
+ *   </informalexample>
+ *   <example id="ClutterAnimator-script-example">
+ *     <title>ClutterAnimator definition</title>
+ *     <para>The following JSON fragment defines a #ClutterAnimator
+ *     with the duration of 1 second and operating on the x and y
+ *     properties of a #ClutterActor named "rect-01", with two frames
+ *     for each property. The first frame will linearly move the actor
+ *     from its current position to the 100, 100 position in 20 percent
+ *     of the duration of the animation; the second will using a cubic
+ *     easing to move the actor to the 200, 200 coordinates.</para>
+ *     <programlisting><![CDATA[
  *  {
  *    "type" : "ClutterAnimator",
  *    "duration" : 1000,
@@ -112,7 +113,13 @@
  *      }
  *    ]
  *  }
- * ]|
+ *     ]]></programlisting>
+ *   </example>
+ * </refsect2>
+ *
+ * #ClutterAnimator is available since Clutter 1.2
+ *
+ * #ClutterAnimator has been deprecated in Clutter 1.12
  */
 
 #ifdef HAVE_CONFIG_H
@@ -136,6 +143,8 @@
 #include "clutter-script-private.h"
 #include "clutter-scriptable.h"
 
+#define CLUTTER_ANIMATOR_GET_PRIVATE(obj)       (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_ANIMATOR, ClutterAnimatorPrivate))
+
 /* progress values varying by less than this are considered equal */
 #define PROGRESS_EPSILON  0.00001
 
@@ -194,7 +203,6 @@ static void clutter_scriptable_init (ClutterScriptableIface *iface);
 G_DEFINE_TYPE_WITH_CODE (ClutterAnimator,
                          clutter_animator,
                          G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (ClutterAnimator)
                          G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
                                                 clutter_scriptable_init));
 /**
@@ -1198,10 +1206,6 @@ clutter_animator_set (ClutterAnimator *animator,
 
   object = first_object;
   property_name = first_property_name;
-
-  g_return_if_fail (object);
-  g_return_if_fail (property_name);
-
   mode = first_mode;
   progress = first_progress;
 
@@ -1214,6 +1218,9 @@ clutter_animator_set (ClutterAnimator *animator,
       GValue value = G_VALUE_INIT;
       gchar *error = NULL;
 
+      g_return_if_fail (object);
+      g_return_if_fail (property_name);
+
       klass = G_OBJECT_GET_CLASS (object);
       pspec = g_object_class_find_property (klass, property_name);
 
@@ -1775,6 +1782,8 @@ clutter_animator_class_init (ClutterAnimatorClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
+  g_type_class_add_private (klass, sizeof (ClutterAnimatorPrivate));
+
   gobject_class->set_property = clutter_animator_set_property;
   gobject_class->get_property = clutter_animator_get_property;
   gobject_class->dispose = clutter_animator_dispose;
@@ -1824,7 +1833,7 @@ clutter_animator_init (ClutterAnimator *animator)
   ClutterAnimatorPrivate *priv;
   ClutterTimeline *timeline;
 
-  animator->priv = priv = clutter_animator_get_instance_private (animator);
+  animator->priv = priv = CLUTTER_ANIMATOR_GET_PRIVATE (animator);
 
   priv->properties = g_hash_table_new_full (prop_actor_hash,
                                             prop_actor_equal,
